<?php
/*
 * This file is part of the Manualranking Product plugin
 *
 * Copyright (C) 2016 LOCKON CO.,LTD. All Rights Reserved.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Plugin\Manualranking\Repository;

use Doctrine\ORM\EntityRepository;
use Eccube\Entity\Master\Disp;
use Plugin\Manualranking\Entity\ManualrankingProduct;

/**
 * ManualrankingProductRepository.
 *
 * This class was generated by the Doctrine ORM. Add your own custom
 * repository methods below.
 */
class ManualrankingProductRepository extends EntityRepository
{
    /**
     * Find list.
     *
     * @return mixed
     */
    public function getManualrankingList()
    {
        $qb = $this->createQueryBuilder('rp')
            ->innerJoin('rp.Product', 'p');
        $qb->addOrderBy('rp.rank', 'DESC');

        return $qb->getQuery()->getResult();
    }

    /**
     * Get max rank.
     *
     * @return mixed
     */
    public function getMaxRank()
    {
        // 最大のランクを取得する.
        $sql = "SELECT MAX(m.rank) AS max_rank FROM Plugin\Manualranking\Entity\ManualrankingProduct m";
        $q = $this->getEntityManager()->createQuery($sql);

        return $q->getSingleScalarResult();
    }

    /**
     * Get manualranking product by display status of product.
     *
     * @param Disp $Disp
     *
     * @return array
     */
    public function getManualrankingProduct(Disp $Disp)
    {
        $query = $this->createQueryBuilder('rp')
            ->innerJoin('Eccube\Entity\Product', 'p', 'WITH', 'p.id = rp.Product')
            ->where('p.Status = :Disp')
            ->orderBy('rp.rank', 'DESC')
            ->setParameter('Disp', $Disp)
            ->getQuery();

        return $query->getResult();
    }

    /**
     * Number of manualranking.
     *
     * @return int
     */
    public function countManualranking()
    {
        $qb = $this->createQueryBuilder('rp');
        $qb->select('COUNT(rp)');

        return $qb->getQuery()->getSingleScalarResult();
    }

    /**
     * Move rank.
     *
     * @param array $arrRank
     *
     * @return bool
     *
     * @throws \Exception
     */
    public function moveManualrankingRank(array $arrRank)
    {
        $this->getEntityManager()->beginTransaction();
        $arrRankMoved = array();
        try {
            foreach ($arrRank as $manualrankingId => $rank) {
                /* @var $Manualranking ManualrankingProduct */
                $Manualranking = $this->find($manualrankingId);
                if ($Manualranking->getRank() == $rank) {
                    continue;
                }
                $arrRankMoved[$manualrankingId] = $rank;
                $Manualranking->setRank($rank);
                $this->getEntityManager()->persist($Manualranking);
            }
            $this->getEntityManager()->flush();
            $this->getEntityManager()->commit();
        } catch (\Exception $e) {
            $this->getEntityManager()->rollback();
            throw $e;
        }

        return $arrRankMoved;
    }

    /**
     * Save manualranking.
     *
     * @param ManualrankingProduct $ManualrankingProduct
     *
     * @return bool
     *
     * @throws \Exception
     */
    public function saveManualranking(ManualrankingProduct $ManualrankingProduct)
    {
        $this->getEntityManager()->beginTransaction();
        try {
            $this->getEntityManager()->persist($ManualrankingProduct);
            $this->getEntityManager()->flush();
            $this->getEntityManager()->commit();
        } catch (\Exception $e) {
            $this->getEntityManager()->rollback();
            throw $e;
        }

        return true;
    }

    /**
     * Get all id of manualranking product.
     *
     * @return array
     */
    public function getManualrankingProductIdAll()
    {
        $query = $this->createQueryBuilder('rp')
            ->select('IDENTITY(rp.Product) as id')
            ->getQuery();
        $arrReturn = $query->getScalarResult();

        return array_map('current', $arrReturn);
    }
}
