<?php
/*
 * This file is part of the Manualranking Product plugin
 *
 * Copyright (C) 2016 LOCKON CO.,LTD. All Rights Reserved.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Plugin\Manualranking\Service;

use Eccube\Common\Constant;
use Plugin\Manualranking\Entity\ManualrankingProduct;

/**
 * Class ManualrankingService.
 */
class ManualrankingService
{
    /** @var \Eccube\Application */
    public $app;

    /**
     * コンストラクタ
     *
     * @param \Eccube\Application $app
     */
    public function __construct($app)
    {
        $this->app = $app;
    }

    /**
     * 手動売上ランキング情報を新規登録する.
     *
     * @param array $data
     *
     * @return bool
     */
    public function createManualranking($data)
    {
        // 手動売上ランキング詳細情報を生成する
        $Manualranking = $this->newManualranking($data);

        return $this->app['eccube.plugin.manualranking.repository.manualranking_product']->saveManualranking($Manualranking);
    }

    /**
     * 手動売上ランキング情報を更新する.
     *
     * @param array $data
     *
     * @return bool
     */
    public function updateManualranking($data)
    {
        // 手動売上ランキング情報を取得する
        $Manualranking = $this->app['eccube.plugin.manualranking.repository.manualranking_product']->find($data['id']);
        if (!$Manualranking) {
            return false;
        }

        // 手動売上ランキング情報を書き換える
        $Manualranking->setComment($data['comment']);
        $Manualranking->setProduct($data['Product']);

        // 手動売上ランキング情報を更新する
        return $this->app['eccube.plugin.manualranking.repository.manualranking_product']->saveManualranking($Manualranking);
    }

    /**
     * 手動売上ランキング情報を削除する.
     *
     * @param int $manualrankingId
     *
     * @return bool
     */
    public function deleteManualranking($manualrankingId)
    {
        // 手動売上ランキング情報を取得する
        $Manualranking = $this->app['eccube.plugin.manualranking.repository.manualranking_product']->find($manualrankingId);
        if (!$Manualranking) {
            return false;
        }
        // 手動売上ランキング情報を書き換える
        $Manualranking->setDelFlg(Constant::ENABLED);

        // 手動売上ランキング情報を登録する
        return $this->app['eccube.plugin.manualranking.repository.manualranking_product']->saveManualranking($Manualranking);
    }

    /**
     * 手動売上ランキング情報を生成する.
     *
     * @param array $data
     *
     * @return ManualrankingProduct
     */
    protected function newManualranking($data)
    {
        $rank = $this->app['eccube.plugin.manualranking.repository.manualranking_product']->getMaxRank();

        $Manualranking = new ManualrankingProduct();
        $Manualranking->setComment($data['comment']);
        $Manualranking->setProduct($data['Product']);
        $Manualranking->setRank(($rank ? $rank : 0) + 1);
        $Manualranking->setDelFlg(Constant::DISABLED);

        return $Manualranking;
    }
}
